@@ -18,8 +18,11 @@ int	argc;
 char	*argv[];
 {
 	FILE	*PidFile;
-	struct  hostent *hp;
 
+	logfile = fopen (LOGFILE, "a");
+	now = time(NULL);
+	fprintf (logfile, "%24.24s TrustDB Start\n",ctime(&now));
+	fclose (logfile);
 	TrustDB_in = 0;
 	TrustDB_out = 0;
 	cmdin = 0;
@@ -32,7 +35,10 @@ char	*argv[];
         PidFile = fopen ("/var/run/dstrustdb.pid","w");
         if (PidFile == NULL)
         {
-                printf ("must run on supper user\n");
+		logfile = fopen (LOGFILE, "a");
+		now = time(NULL);
+                fprintf (logfile, "%24.24s must run on supper user\n", ctime(&now));
+		fclose (logfile);
                 exit(-1);
         }
         fprintf (PidFile, "%d\n",(int)getpid());
@@ -49,16 +55,16 @@ char	*argv[];
                 cmdin = open ("/tmp/dstrustdb-cmdin", O_NONBLOCK | O_RDONLY);
                 if (cmdin < 0)
                 {
-                        printf ("ERROR FIFO file not open /tmp/dstrustdb-cmdin\n");
+			logfile = fopen (LOGFILE, "a");
+			now = time(NULL);
+                        fprintf (logfile, "%24.24s ERROR FIFO file not open /tmp/dstrustdb-cmdin\n", ctime(&now));
+			fclose (logfile);
                         cmdin = 0;
                 }
         }
 
 	DB_connect();	
 
-        hp = gethostbyname(TrustDbDomainName);
-        bcopy(hp->h_addr, &dbIP, hp->h_length);
-
 	InitSocket();
 	InitSignal();
 	MainLoop();
@@ -66,37 +72,30 @@ char	*argv[];
 
 int InitSocket(void)
 {
-	char	hostname[MAXHOSTNAMELEN];
-	struct	hostent	*myhost;
 	int	opt;
-
-	DB(fprintf(stderr,"InitSocket\n"));
+	struct	hostent	*hp;
 
 
         if ((TrustDB_in = socket(PF_INET,SOCK_DGRAM,0)) < 0){
                 perror("socket:TrustDB_in");
                 exit(-1);
         }
-        DB(fprintf(stderr,"socket:TrustDB_in:OK\n"));
 
         opt=1;
         if (setsockopt(TrustDB_in,SOL_SOCKET,SO_REUSEADDR,&opt,sizeof(int)) != 0){
                 perror("setsockopt");
                 exit(-1);
         }
-        DB(fprintf(stderr,"setsockopt:OK\n"));
 
         if ((TrustDB_out = socket(PF_INET,SOCK_DGRAM,0)) < 0){
                 perror("socket:TrustDB_out");
                 exit(-1);
         }
-        DB(fprintf(stderr,"socket:TrustDB_out:OK\n"));
         opt=1;
         if (setsockopt(TrustDB_out,SOL_SOCKET,SO_REUSEADDR,&opt,sizeof(int)) != 0){
                 perror("setsockopt");
                 exit(-1);
         }
-        DB(fprintf(stderr,"setsockopt:OK\n"));
 	memset((char *)&db_out,0,sizeof(db_out));
 	db_out.sin_family=PF_INET;
 	db_out.sin_port=dbOutPort;
@@ -104,28 +103,30 @@ int InitSocket(void)
 		perror("bind:db_out");
 		exit(-1);
 	}
-	DB(fprintf(stderr,"bind:db:OK\n"));
+
+        hp = gethostbyname(TrustDbDomainName);
+        memcpy (&dbIP, hp->h_addr_list[0], hp->h_length);
 
 	return(0);
 }
 
 void CloseSocket()
 {
-	DB(fprintf(stderr,"CloseSocket\n"));
         if(TrustDB_in != 0){
                 close(TrustDB_in);
-                DB(fprintf(stderr,"close(TrustDB_in)\n"));
                 TrustDB_in = 0;
         }
         if(TrustDB_out != 0){
                 close(TrustDB_out);
-                DB(fprintf(stderr,"close(TrustDB_out)\n"));
                 TrustDB_out = 0;
         }
-	DB(fprintf(stderr,"CloseSocket:exit\n"));
 
 	PQfinish (conDB);
 
+        logfile = fopen (LOGFILE, "a");
+        now = time(NULL);
+        fprintf (logfile, "%24.24s TrustDB End\n",ctime(&now));
+        fclose (logfile);
 	exit(0);
 }
 
@@ -133,15 +134,12 @@ void CloseChild()
 {
 	int	pid;
 
-	DB(fprintf(stderr,"CloseChild\n"));
 	pid=wait(0);
-	DB(fprintf(stderr,"wait:pid=%d:end\n",pid));
 	signal(SIGCLD,CloseChild);
 }
 
 int InitSignal()
 {
-	DB(fprintf(stderr,"InitSignal\n"));
 	signal(SIGINT,CloseSocket);
 	signal(SIGTERM,CloseSocket);
 	signal(SIGCLD,CloseChild);
@@ -157,8 +155,11 @@ void	DB_connect(void)
 	conDB = PQconnectdb (string);
 	if (PQstatus(conDB) == CONNECTION_BAD)
 	{
-		printf(" データベース '%s' への接続に失敗しました \n" ,DBNAME);
-		printf("%s", PQerrorMessage(conDB));
+		logfile = fopen (LOGFILE, "a");
+		now = time(NULL);
+		fprintf(logfile, "%24.24s  データベース '%s' への接続に失敗しました \n" ,ctime(&now), DBNAME);
+		fprintf(logfile, "%24.24s %s\n", ctime(&now), PQerrorMessage(conDB));
+		fclose (logfile);
 		exit(0);
 	}
 }
@@ -171,8 +172,6 @@ void MainLoop(void)
 	struct	timeval	timeout;
 	char	client[64];
 
-	DB(fprintf(stderr,"MainLoop\n"));
-
 	FD_ZERO(&Mask);
 	FD_SET(TrustDB_out, &Mask);
 	FD_SET(cmdin, &Mask);
@@ -224,8 +223,6 @@ int DoKeyInCommand(char *str)
 		if (str[n] == 0x0d) str[n] = 0x00;
 	}
 
-	DB(fprintf(stderr,"(%s)\n",str));
-
 	if (strlen(str))
 	{
 		if((strncmp(str,"end", strlen(str))==0) 
