@@ -14,3 +14,12 @@ CREATE TABLE repeater (
 	trust_name	CHAR(16),
 	u_time		TIMESTAMP
 );
+
+DROP TABLE trust;
+
+CREATE TABLE trust (
+	trust_name	CHAR(16) PRIMARY KEY,
+	trust_ip	INET,
+	trust_port	INT
+);
+
